@@ -1,13 +1,10 @@
 r"""Directed Acyclic Workflow Graph Scheduling"""
 
-__version__ = '0.1.2'
-
-
 from functools import partial
-from typing import Callable, Union
+from typing import *
 
-from .workflow import Job
 from .schedulers import schedule
+from .workflow import Job, leafs, roots
 
 
 def job(f: Callable = None, /, **kwargs) -> Union[Callable, Job]:
@@ -39,3 +36,11 @@ def ensure(condition: Callable) -> Callable:
         return self
 
     return decorator
+
+
+def context(**kwargs) -> Callable:
+    def decorator(self: Job) -> Job:
+        self.context.update(kwargs)
+        return self
+
+    return decorator
